@@ -24,6 +24,9 @@ func NoteAction(writer io.Writer, actionName, noteID, newNoteID string, tuneApp
 	case "verify":
 		NoteActionVerify(writer, noteID, tuneApp)
 	case "simulate":
+		if system.IfdefVers() > 15 {
+			PrintHelpAndExit(writer, 1)
+		}
 		system.WarningLog("the action 'note simulate' is deprecated!.\nsaptune will still handle this action in the current version, but it will be removed in future versions of saptune.")
 		NoteActionSimulate(writer, noteID, tuneApp)
 	case "customise", "customize":
@@ -37,7 +40,7 @@ func NoteAction(writer io.Writer, actionName, noteID, newNoteID string, tuneApp
 	case "delete":
 		NoteActionDelete(os.Stdin, writer, noteID, tuneApp)
 	case "refresh":
-		NoteActionRefresh(writer, noteID, tuneApp)
+		NoteActionRefresh(os.Stdin, writer, noteID, tuneApp)
 	case "rename":
 		NoteActionRename(os.Stdin, writer, noteID, newNoteID, tuneApp)
 	case "revert":
@@ -153,8 +156,10 @@ func setupNoteListFormat(noteID string, solutionNoteIDs []string, tuneApp *app.A
 // NoteActionVerify compares all parameter settings from a Note definition
 // against the system settings
 func NoteActionVerify(writer io.Writer, noteID string, tuneApp *app.App) {
-	if noteID == "" || noteID == "applied" {
-		VerifyAllParameters(writer, tuneApp)
+	if noteID == "" {
+		VerifyAllParameters(writer, tuneApp, false)
+	} else if noteID == "applied" {
+		VerifyAllParameters(writer, tuneApp, true)
 	} else {
 		result := system.JPNotes{
 			Verifications: []system.JPNotesLine{},
@@ -486,7 +491,14 @@ func NoteActionApplied(writer io.Writer, tuneApp *app.App) {
 
 // NoteActionRefresh re-applies Note parameter settings to the system
 // if an already applied Note got changed.
-func NoteActionRefresh(writer io.Writer, noteID string, tuneApp *app.App) {
+func NoteActionRefresh(reader io.Reader, writer io.Writer, noteID string, tuneApp *app.App) {
+	system.NoticeLog("ATTENTION: the action 'note refresh' is experimental!")
+	txtConfirm := fmt.Sprintf("Do you really want to continue to test this experimental action?")
+	if !readYesNo(txtConfirm, reader, writer) {
+		system.NoticeLog("Note action 'refresh' aborted by user interaction")
+		system.ErrorExit("", 0)
+	}
+
 	errCount := 0
 	noteList := make([]string, 0)
 	if noteID == "" || noteID == "applied" {
